module Transmission
  class Client
    include HTTParty

    attr_reader :base_uri, :auth, :headers

    def initialize( host = "localhost", port = 9091, username = nil, password = nil )
      @base_uri = "http://#{host}:#{port}/transmission/rpc"
      @auth = { username: username, password: password }
      @headers = { "x-transmission-session-id" => "" }
    end

    def session_id
      @headers["x-transmission-session-id"]
    end

    def torrent_start( ids = nil )
      TorrentStart.new( self, ids ).request
    end

    def torrent_start_now( ids = nil )
      TorrentStartNow.new( self, ids ).request
    end

    def torrent_stop( ids = nil )
      TorrentStop.new( self, ids ).request
    end

    def torrent_verify( ids = nil )
      TorrentVerify.new( self, ids ).request
    end

    def torrent_reannounce( ids = nil )
      TorrentReannounce.new( self, ids ).request
    end

    def torrent_set( arguments = {}, ids = nil )
      TorrentSet.new( self, arguments, ids  ).request
    end

    def torrent_get( fields = nil, ids = nil )
      TorrentGet.new( self, fields, ids ).request
    end

    def torrent_add( arguments = {} )
      TorrentAdd.new( self, arguments ).request
    end

    def torrent_remove( delete = false, ids = nil )
      TorrentRemove.new( self, delete, ids ).request
    end
  end
end